chatter.migrations package — django-chats 0.1.1 documentation

# chatter.migrations package

## Submodules

## chatter.migrations.0001_initial module

## chatter.migrations.0002_auto_20200922_1209 module

## chatter.migrations.0003_auto_20200922_1221 module

class `chatter.migrations.0003_auto_20200922_1221.` `Migration`(name, app_label)

  Bases: `django.db.migrations.migration.Migration`

  `dependencies` = [('chatter', '0002_auto_20200922_1209')]
  `operations` = [<RenameField model_name='message', old_name='body', new_name='content'>, <RemoveField model_name='message', name='title'>]

## chatter.migrations.0004_auto_20200925_1757 module

## chatter.migrations.0005_auto_20200925_1856 module

class `chatter.migrations.0005_auto_20200925_1856.` `Migration`(name, app_label)

  Bases: `django.db.migrations.migration.Migration`

  `dependencies` = [('chatter', '0004_auto_20200925_1757')]
  `operations` = [<AlterModelManagers name='message', managers=[]>]

## Module contents